@@ -11,7 +11,7 @@ use warnings;
 
 package Dist::Zilla::PluginBundle::Author::JMASLAK;
 # ABSTRACT: JMASLAK's Plugin Bundle
-$Dist::Zilla::PluginBundle::Author::JMASLAK::VERSION = '1.181840';
+$Dist::Zilla::PluginBundle::Author::JMASLAK::VERSION = '1.181841';
 
 use Moose;
 use Dist::Zilla;
@@ -113,9 +113,9 @@ sub configure {
     $self->add_plugins('UploadToCPAN');
 
     $self->add_plugins(
-        'Git::Check', => { allow_dirty => [ 'dist.ini', _changes_file(), 'README.pod' ] } );
+        [ 'Git::Check', => { allow_dirty => [ 'dist.ini', _changes_file(), 'README.pod' ] } ] );
     $self->add_plugins(
-        'Git::Commit', => { allow_dirty => [ 'dist.ini', _changes_file(), 'README.pod' ] } );
+        [ 'Git::Commit', => { allow_dirty => [ 'dist.ini', _changes_file(), 'README.pod' ] } ] );
     $self->add_plugins('Git::Push');
     $self->add_plugins('Git::Tag');
 
@@ -265,7 +265,7 @@ Dist::Zilla::PluginBundle::Author::JMASLAK - JMASLAK's Plugin Bundle
 
 =head1 VERSION
 
-version 1.181840
+version 1.181841
 
 =head1 DESCRIPTION
 
